:mod:`bdbcontrib.predictors.keplers_law`: Example domain-specific predictor
===========================================================================

Incorporating Kepler's Third Law to relate period, perigee and apogee
in satellite data, as an example of including domain knowledge in
BayesDB as a foreign predictor.

.. automodule:: bdbcontrib.predictors.keplers_law
 :members:
